@@ -39,10 +39,12 @@
 #include <dirent.h>
 #include <set>
 #include <errno.h>
+#include <iostream>
 
 #include "readfile.hpp"
 #include "writefile.hpp"
 #include "sha1.hpp"
+#include "xxh64.hpp"
 #include "progress.hpp"
 
 #include "disk.hpp"
@@ -53,6 +55,7 @@ Disk::Disk(const std::string& path)
 : m_path(path)
 , m_verbose(false)
 , m_sparse(false)
+, m_ignore_checksum(false)
 {
 }
 
@@ -111,16 +114,34 @@ bool Disk::Export(const std::string& diskpath)
 					checksum)
 				)
 			{
-				fclose(fp);
-				throw std::runtime_error("unable to read " +
-						std::string(path2) + ".checksum");
-			}
-
-			if (checksum != XVA::SHA1(chunk))
+				if (!XVA::ReadFile(
+						(m_path + "/" + path2 + ".xxhash"),
+						checksum)
+					)
+				{
+					fclose(fp);
+					throw std::runtime_error("unable to read " +
+							std::string(path2) + ".checksum and " +
+							std::string(path2) + ".xxhash");
+				} else if (checksum != XVA::XXH64(chunk))
+				{
+					if(!m_ignore_checksum)
+					{
+						fclose(fp);
+						throw std::runtime_error("invalid xxh64 checksum for " +
+								std::string(path2));
+					}
+					std::cerr << "invalid xxh64 checksum for " << std::string(path2) << std::endl;
+				}
+			} else if (checksum != XVA::SHA1(chunk))
 			{
-				fclose(fp);
-				throw std::runtime_error("invalid checksum for " +
-						std::string(path2));
+				if(!m_ignore_checksum)
+				{
+					fclose(fp);
+					throw std::runtime_error("invalid sha1 checksum for " +
+							std::string(path2));
+				}
+				std::cerr << "invalid sha1 checksum for " << std::string(path2) << std::endl;
 			}
 
 			if (fwrite(chunk.c_str(), 1, chunk.size(), fp) != chunk.size())
@@ -247,3 +268,8 @@ void Disk::Sparse()
 {
 	m_sparse = true;
 }
+
+void Disk::IgnoreChecksum()
+{
+	m_ignore_checksum = true;
+}
